@@ -116,7 +116,7 @@
  * Get all of the headers from the request.
  *
  * @param connection connection to get values from
- * @param kind types of values to iterate over
+ * @param kind types of values to iterate over, can be a bitmask
  * @param iterator callback to call on each header;
  *        maybe NULL (then just count headers)
  * @param iterator_cls extra argument to @a iterator
@@ -126,7 +126,8 @@
 int
 MHD_get_connection_values (struct MHD_Connection *connection,
                            enum MHD_ValueKind kind,
-                           MHD_KeyValueIterator iterator, void *iterator_cls)
+                           MHD_KeyValueIterator iterator,
+                           void *iterator_cls)
 {
   int ret;
   struct MHD_HTTP_Header *pos;
@@ -138,9 +139,11 @@ MHD_get_connection_values (struct MHD_Connection *connection,
     if (0 != (pos->kind & kind))
       {
 	ret++;
-	if ((NULL != iterator) &&
-	    (MHD_YES != iterator (iterator_cls,
-				  kind, pos->header, pos->value)))
+	if ( (NULL != iterator) &&
+             (MHD_YES != iterator (iterator_cls,
+                                   pos->kind,
+                                   pos->header,
+                                   pos->value)) )
 	  return ret;
       }
   return ret;
@@ -264,8 +267,8 @@ need_100_continue (struct MHD_Connection *connection)
  * @param termination_code termination reason to give
  */
 void
-MHD_connection_close (struct MHD_Connection *connection,
-                      enum MHD_RequestTerminationCode termination_code)
+MHD_connection_close_ (struct MHD_Connection *connection,
+                       enum MHD_RequestTerminationCode termination_code)
 {
   struct MHD_Daemon *daemon;
 
@@ -300,8 +303,8 @@ connection_close_error (struct MHD_Connection *connection,
   if (NULL != emsg)
     MHD_DLOG (connection->daemon, emsg);
 #endif
-  MHD_connection_close (connection,
-			MHD_REQUEST_TERMINATED_WITH_ERROR);
+  MHD_connection_close_ (connection,
+                         MHD_REQUEST_TERMINATED_WITH_ERROR);
 }
 
 
@@ -368,8 +371,8 @@ try_ready_normal_body (struct MHD_Connection *connection)
       if (NULL != response->crc)
         (void) MHD_mutex_unlock_ (&response->mutex);
       if ( ((ssize_t)MHD_CONTENT_READER_END_OF_STREAM) == ret)
-	MHD_connection_close (connection,
-			      MHD_REQUEST_TERMINATED_COMPLETED_OK);
+	MHD_connection_close_ (connection,
+                               MHD_REQUEST_TERMINATED_COMPLETED_OK);
       else
 	CONNECTION_CLOSE_ERROR (connection,
 				"Closing connection (stream error)\n");
@@ -1176,17 +1179,22 @@ get_next_header_line (struct MHD_Connection *connection)
  */
 static int
 connection_add_header (struct MHD_Connection *connection,
-                       char *key, char *value, enum MHD_ValueKind kind)
+                       const char *key,
+		       const char *value,
+		       enum MHD_ValueKind kind)
 {
-  if (MHD_NO == MHD_set_connection_value (connection,
-					  kind,
-					  key, value))
+  if (MHD_NO ==
+      MHD_set_connection_value (connection,
+				kind,
+				key,
+				value))
     {
 #if HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
                 "Not enough memory to allocate header record!\n");
 #endif
-      transmit_error_response (connection, MHD_HTTP_REQUEST_ENTITY_TOO_LARGE,
+      transmit_error_response (connection,
+			       MHD_HTTP_REQUEST_ENTITY_TOO_LARGE,
                                REQUEST_TOO_BIG);
       return MHD_NO;
     }
@@ -1194,99 +1202,10 @@ connection_add_header (struct MHD_Connection *connection,
 }
 
 
-/**
- * Parse and unescape the arguments given by the client as part
- * of the HTTP request URI.
- *
- * @param kind header kind to use for adding to the connection
- * @param connection connection to add headers to
- * @param args argument URI string (after "?" in URI)
- * @return #MHD_NO on failure (out of memory), #MHD_YES for success
- */
-static int
-parse_arguments (enum MHD_ValueKind kind,
-                 struct MHD_Connection *connection,
-		 char *args)
-{
-  char *equals;
-  char *amper;
-
-  while (NULL != args)
-    {
-      equals = strchr (args, '=');
-      amper = strchr (args, '&');
-      if (NULL == amper)
-	{
-	  /* last argument */
-	  if (NULL == equals)
-	    {
-	      /* got 'foo', add key 'foo' with NULL for value */
-              MHD_unescape_plus (args);
-	      connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-						     connection,
-						     args);
-	      return connection_add_header (connection,
-					    args,
-					    NULL,
-					    kind);
-	    }
-	  /* got 'foo=bar' */
-	  equals[0] = '\0';
-	  equals++;
-          MHD_unescape_plus (args);
-	  connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-						 connection,
-						 args);
-          MHD_unescape_plus (equals);
-	  connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-						 connection,
-						 equals);
-	  return connection_add_header (connection, args, equals, kind);
-	}
-      /* amper is non-NULL here */
-      amper[0] = '\0';
-      amper++;
-      if ( (NULL == equals) ||
-	   (equals >= amper) )
-	{
-	  /* got 'foo&bar' or 'foo&bar=val', add key 'foo' with NULL for value */
-          MHD_unescape_plus (args);
-	  connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-						 connection,
-						 args);
-	  if (MHD_NO ==
-	      connection_add_header (connection,
-				     args,
-				     NULL,
-				     kind))
-	    return MHD_NO;
-	  /* continue with 'bar' */
-	  args = amper;
-	  continue;
-	}
-      /* equals and amper are non-NULL here, and equals < amper,
-	 so we got regular 'foo=value&bar...'-kind of argument */
-      equals[0] = '\0';
-      equals++;
-      MHD_unescape_plus (args);
-      connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-					     connection,
-					     args);
-      MHD_unescape_plus (equals);
-      connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-					     connection,
-					     equals);
-      if (MHD_NO == connection_add_header (connection, args, equals, kind))
-        return MHD_NO;
-      args = amper;
-    }
-  return MHD_YES;
-}
-
-
 /**
  * Parse the cookie header (see RFC 2109).
  *
+ * @param connection connection to parse header of
  * @return #MHD_YES for success, #MHD_NO for failure (malformed, out of memory)
  */
 static int
@@ -1372,8 +1291,11 @@ parse_cookie_header (struct MHD_Connection *connection)
           equals[strlen (equals) - 1] = '\0';
           equals++;
         }
-      if (MHD_NO == connection_add_header (connection,
-                                           pos, equals, MHD_COOKIE_KIND))
+      if (MHD_NO ==
+	  connection_add_header (connection,
+				 pos,
+				 equals,
+				 MHD_COOKIE_KIND))
         return MHD_NO;
       pos = semicolon;
     }
@@ -1392,9 +1314,11 @@ static int
 parse_initial_message_line (struct MHD_Connection *connection,
                             char *line)
 {
+  struct MHD_Daemon *daemon = connection->daemon;
   char *uri;
   char *http_version;
   char *args;
+  unsigned int unused_num_headers;
 
   if (NULL == (uri = strchr (line, ' ')))
     return MHD_NO;              /* serious error */
@@ -1409,21 +1333,26 @@ parse_initial_message_line (struct MHD_Connection *connection,
       http_version[0] = '\0';
       http_version++;
     }
-  if (NULL != connection->daemon->uri_log_callback)
+  if (NULL != daemon->uri_log_callback)
     connection->client_context
-      = connection->daemon->uri_log_callback (connection->daemon->uri_log_callback_cls,
-					      uri,
-					      connection);
+      = daemon->uri_log_callback (daemon->uri_log_callback_cls,
+				  uri,
+				  connection);
   args = strchr (uri, '?');
   if (NULL != args)
     {
       args[0] = '\0';
       args++;
-      parse_arguments (MHD_GET_ARGUMENT_KIND, connection, args);
+      /* note that this call clobbers 'args' */
+      MHD_parse_arguments_ (connection,
+			    MHD_GET_ARGUMENT_KIND,
+			    args,
+			    &connection_add_header,
+			    &unused_num_headers);
     }
-  connection->daemon->unescape_callback (connection->daemon->unescape_callback_cls,
-					 connection,
-					 uri);
+  daemon->unescape_callback (daemon->unescape_callback_cls,
+			     connection,
+			     uri);
   connection->url = uri;
   if (NULL == http_version)
     connection->version = "";
@@ -1685,8 +1614,8 @@ do_read (struct MHD_Connection *connection)
       /* other side closed connection; RFC 2616, section 8.1.4 suggests
 	 we should then shutdown ourselves as well. */
       connection->read_closed = MHD_YES;
-      MHD_connection_close (connection,
-			    MHD_REQUEST_TERMINATED_CLIENT_ABORT);
+      MHD_connection_close_ (connection,
+                             MHD_REQUEST_TERMINATED_CLIENT_ABORT);
       return MHD_YES;
     }
   connection->read_buffer_offset += bytes_read;
@@ -1858,7 +1787,9 @@ process_broken_line (struct MHD_Connection *connection,
     }
   EXTRA_CHECK ((NULL != last) && (NULL != connection->colon));
   if ((MHD_NO == connection_add_header (connection,
-                                        last, connection->colon, kind)))
+                                        last,
+					connection->colon,
+					kind)))
     {
       transmit_error_response (connection, MHD_HTTP_REQUEST_ENTITY_TOO_LARGE,
                                REQUEST_TOO_BIG);
@@ -2031,8 +1962,8 @@ MHD_connection_handle_read (struct MHD_Connection *connection)
           /* nothing to do but default action */
           if (MHD_YES == connection->read_closed)
             {
-	      MHD_connection_close (connection,
-				    MHD_REQUEST_TERMINATED_READ_ERROR);
+	      MHD_connection_close_ (connection,
+                                     MHD_REQUEST_TERMINATED_READ_ERROR);
               continue;
             }
           break;
@@ -2611,8 +2542,8 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
               (MHD_NO == keepalive_possible (connection)))
             {
               /* have to close for some reason */
-              MHD_connection_close (connection,
-                                    MHD_REQUEST_TERMINATED_COMPLETED_OK);
+              MHD_connection_close_ (connection,
+                                     MHD_REQUEST_TERMINATED_COMPLETED_OK);
               MHD_pool_destroy (connection->pool);
               connection->pool = NULL;
               connection->read_buffer = NULL;
@@ -2627,7 +2558,7 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
               connection->read_buffer
                 = MHD_pool_reset (connection->pool,
                                   connection->read_buffer,
-                                  connection->read_buffer_size);
+                                  connection->read_buffer_offset);
             }
 	  connection->client_aware = MHD_NO;
           connection->client_context = NULL;
@@ -2657,8 +2588,8 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
   if ( (0 != timeout) &&
        (timeout <= (MHD_monotonic_sec_counter() - connection->last_activity)) )
     {
-      MHD_connection_close (connection,
-			    MHD_REQUEST_TERMINATED_TIMEOUT_REACHED);
+      MHD_connection_close_ (connection,
+                             MHD_REQUEST_TERMINATED_TIMEOUT_REACHED);
       connection->in_idle = MHD_NO;
       return MHD_YES;
     }
