@@ -1,6 +1,6 @@
 /*
   This file is part of libmicrohttpd
-  (C) 2007, 2010 Christian Grothoff
+  Copyright (C) 2007, 2010 Christian Grothoff
   
   libmicrohttpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
   
   You should have received a copy of the GNU General Public License
   along with libmicrohttpd; see the file COPYING.  If not, write to the
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -134,53 +134,6 @@ main (int argc, char *const *argv)
       fprintf (stderr, "TLS1.0-AES-SHA1 test failed\n");
       errorCount++;
     }
-#if 0
-  /* this used to work, but somehow no longer.  gnutls issue? */
-  if (0 != 
-      test_wrap ("SSL3.0-AES256-SHA1", 
-		 &test_https_transfer, NULL, daemon_flags,
-		 aes256_sha,
-		 CURL_SSLVERSION_SSLv3,
-		 MHD_OPTION_HTTPS_MEM_KEY, srv_key_pem,
-		 MHD_OPTION_HTTPS_MEM_CERT, srv_self_signed_cert_pem,
-		 MHD_OPTION_HTTPS_PRIORITIES, "NONE:+VERS-SSL3.0:+AES-256-CBC:+SHA1:+RSA:+COMP-NULL",
-	       MHD_OPTION_END))
-    {
-      fprintf (stderr, "SSL3.0-AES256-SHA1 test failed\n");
-      errorCount++;
-    }
-  if (0 !=
-      test_wrap ("SSL3.0-AES-SHA1",
-		 &test_https_transfer, NULL, daemon_flags,
-		 aes128_sha,
-		 CURL_SSLVERSION_SSLv3,
-		 MHD_OPTION_HTTPS_MEM_KEY, srv_key_pem,
-		 MHD_OPTION_HTTPS_MEM_CERT, srv_self_signed_cert_pem,
-		 MHD_OPTION_HTTPS_PRIORITIES, "NONE:+VERS-SSL3.0:+AES-128-CBC:+SHA1:+RSA:+COMP-NULL",
-		 MHD_OPTION_END))
-    {
-      fprintf (stderr, "SSL3.0-AES-SHA1 test failed\n");
-      errorCount++;
-    }
-#endif
-
-
-#if 0
-  /* manual inspection of the handshake suggests that CURL will
-     request TLSv1, we send back "SSL3" and CURL takes it *despite*
-     being configured to speak SSL3-only.  Notably, the other way
-     round (have curl request SSL3, respond with TLSv1 only)
-     is properly refused by CURL.  Either way, this does NOT seem
-     to be a bug in MHD/gnuTLS but rather in CURL; hence this
-     test is commented out here... */
-  errorCount +=
-    test_wrap ("unmatching version: SSL3 vs. TLS", &test_unmatching_ssl_version,
-               NULL, daemon_flags, "AES256-SHA", CURL_SSLVERSION_TLSv1,
-               MHD_OPTION_HTTPS_MEM_KEY, srv_key_pem,
-               MHD_OPTION_HTTPS_MEM_CERT, srv_self_signed_cert_pem,
-               MHD_OPTION_CIPHER_ALGORITHM, "SSL3", MHD_OPTION_END);
-#endif
-
   fprintf (stderr,
 	   "The following handshake should fail (and print an error message)...\n");
   if (0 !=
