@@ -14,12 +14,11 @@
 
      You should have received a copy of the GNU General Public License
      along with libmicrohttpd; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
-
 /**
- * @file daemontest_get_sendfile.c
+ * @file test_get_sendfile.c
  * @brief  Testcase for libmicrohttpd response from FD
  * @author Christian Grothoff
  */
@@ -49,7 +48,7 @@
 
 #define TESTSTR "This is the content of the test file we are sending using sendfile (if available)"
 
-char *sourcefile;
+static char *sourcefile;
 
 static int oneone;
 
@@ -60,6 +59,7 @@ struct CBC
   size_t size;
 };
 
+
 static size_t
 copyBuffer (void *ptr, size_t size, size_t nmemb, void *ctx)
 {
@@ -162,6 +162,7 @@ testInternalGet ()
   return 0;
 }
 
+
 static int
 testMultithreadedGet ()
 {
@@ -211,6 +212,7 @@ testMultithreadedGet ()
   return 0;
 }
 
+
 static int
 testMultithreadedPoolGet ()
 {
@@ -261,6 +263,7 @@ testMultithreadedPoolGet ()
   return 0;
 }
 
+
 static int
 testExternalGet ()
 {
@@ -383,6 +386,7 @@ testExternalGet ()
   return 0;
 }
 
+
 static int
 testUnknownPortGet ()
 {
